# pygithubactions
[![CI](https://github.com/lestex/pygithubactions/actions/workflows/main.yml/badge.svg)](https://github.com/lestex/pygithubactions/actions/workflows/main.yml)

### pygithubactions/core
> Core functions for setting results, logging, registering secrets and exporting variables across actions

### Usage
### Import the package

```python
from pygithubactions import core
```

Refer to [core](docs/core.md) for a documentation.
